node_resolver

Struct NodeResolver

pub struct NodeResolver<TEnv: NodeResolverEnv> { /* private fields */ }

Implementations

Source

impl<TEnv: NodeResolverEnv> NodeResolver<TEnv>

pub fn new( env: TEnv, in_npm_pkg_checker: InNpmPackageCheckerRc, npm_pkg_folder_resolver: NpmPackageFolderResolverRc, pkg_json_resolver: PackageJsonResolverRc<TEnv>, ) -> Self

pub fn in_npm_package(&self, specifier: &Url) -> bool

pub fn resolve( &self, specifier: &str, referrer: &Url, referrer_kind: NodeModuleKind, mode: NodeResolutionMode, ) -> Result<NodeResolution, NodeResolveError>

This function is an implementation of defaultResolve in lib/internal/modules/esm/resolve.js from Node.

pub fn resolve_package_subpath_from_deno_module( &self, package_dir: &Path, package_subpath: Option<&str>, maybe_referrer: Option<&Url>, referrer_kind: NodeModuleKind, mode: NodeResolutionMode, ) -> Result<Url, PackageSubpathResolveError>

pub fn resolve_binary_commands( &self, package_folder: &Path, ) -> Result<Vec<String>, ResolveBinaryCommandsError>

pub fn resolve_binary_export( &self, package_folder: &Path, sub_path: Option<&str>, ) -> Result<Url, ResolvePkgJsonBinExportError>

pub fn package_imports_resolve( &self, name: &str, maybe_referrer: Option<&Url>, referrer_kind: NodeModuleKind, referrer_pkg_json: Option<&PackageJson>, conditions: &[&str], mode: NodeResolutionMode, ) -> Result<Url, PackageImportsResolveError>

pub fn package_exports_resolve( &self, package_json_path: &Path, package_subpath: &str, package_exports: &Map<String, Value>, maybe_referrer: Option<&Url>, referrer_kind: NodeModuleKind, conditions: &[&str], mode: NodeResolutionMode, ) -> Result<Url, PackageExportsResolveError>

pub fn handle_if_in_node_modules(&self, specifier: &Url) -> Option<Url>

Resolves a specifier that is pointing into a node_modules folder by canonicalizing it.

Returns None when the specifier is not in a node_modules folder.